==> SightTraining-0.1.11-py3-none-any.whl: spacedefense/config.py <==
configmap = {
    "display_width": 1280,
    "display_height": 720,
    "fullscreen": False,
    "game_time": 600,
    "bgm": {
        "sound": "sounds/bgm3.ogg",
        "sound_volume": 1.0,
    },
    "game_cover": {
        "cover_image": "images/game_cover.png",
        "cover_win": "images/game_cover_win.png",
        "cover_loss": "images/game_cover_loss.png",
    },
    "background": {
        "vmove": {
            "image_sequence": "images/vmove_cambg1",
            "images": ["images/vmove_cambg1/cambg_003.png"],
        },
        "scale": {
            "image": "images/scale_cambg1.png",
        },
        "type": "vmove",
    },
    "stage_angry": {
        "sound": "sounds/stage_angry.ogg",
        "sound_volume": 0.2,
    },
    "stage_pre": {
        "images": "images/stage_pre.png",
        "sound": "sounds/stage_pre.ogg",
        "sound_volume": 0.2,
    },
    "stage_start": {
        "sound": "sounds/stage_start.ogg",
        "sound_volume": 0.2,
    },
    "stage_end_win": {
        "sound": "sounds/stage_end_win.ogg",
        "sound_volume": 0.2,
    },
    "stage_end_loss": {
        "sound": "sounds/stage_end_loss.ogg",
        "sound_volume": 0.2,
    },
    "sufo_join": {
        "sound": "sounds/sufo_join.ogg",
        "sound_volume": 0.2,
    },
    "smyf_join": {
        "sound": "sounds/smyf_join.ogg",
        "sound_volume": 0.2,
    },
    "my_score_step": 5,
    "ufo_score_step": 3,
    "ufo_master": {
        "image_sequence": "images/ufo_master",
        "images": ["images/ufo_master.png"],
        "first_pos": (720, 100),
        "life_value": 20000,
        "shield_value": 500,
        "shield_recharge_step": 5,
        "bullet_color": "cyan",
        "bullet_speed": 7,
        "bullet_damage": 20,
        "bullet_radius": 12,
        "trace_fire_delay": 30,
        "fire_delay": 30,
        "fire_score": 5,
        "fire_sound": "sounds/ufo_fire.ogg",
        "firehit_sound": "sounds/ufo_firehit.ogg",
        "fire_sound_volume": 0.2,
        "firehit_sound_volume": 0.2,
    },
    "ufo_slave": {
        "image_sequence": "images/ufo_slave2",
        "images": ["images/ufo_slave1.png", "images/ufo_slave2.png"],
        "first_pos": (400, -100),
        "score_cast": 50,
        "max_limit": 8,
        "min_limit": 3,
        "shield_value": 50,
        "shield_recharge_step": 10,
        "life_value": 500,
        "bullet_speed": 9,
        "bullet_color": "cyan",
        "bullet_damage": 10,
        "bullet_radius": 10,
        "trace_fire_delay": 40,
        "fire_delay": 15,
        "fire_sound": "sounds/ufo_fire.ogg",
        "firehit_sound": "sounds/ufo_firehit.ogg",
        "fire_sound_volume": 0.2,
        "firehit_sound_volume": 0.2,
    },
    "myf_master": {
        "life_value": 700,
        "shield_value": 300,
        "shield_recharge_step": 3,
        "speed_x": 8,
        "image_sequence": "images/myf_master",
        "image": "images/master_fighter.png",
        "firehit_sound": "sounds/firehit.ogg",
        "fire_sound_volume": 0.2,
        "firehit_sound_volume": 0.2,
        "level1": {
            "bullet_color": "light_yellow",
            "bullet_per_num": 2,
            "bullet_speed": 15,
            "bullet_damage": 15,
            "bullet_radius": 6,
            "fire_delay": 8,
            "fire_sound": "sounds/fire.ogg",
        },
        "level2": {
            "bullet_color": "light_yellow",
            "bullet_per_num": 1,
            "bullet_speed": 10,
            "bullet_damage": 30,
            "bullet_radius": 10,
            "fire_delay": 12,
            "fire_sound": "sounds/fire.ogg",
        },
        "level3": {
            "bullet_color": "light_yellow",
            "bullet_per_num": 2,
            "bullet_speed": 10,
            "bullet_damage": 3,
            "bullet_radius": 5,
            "fire_delay": 10,
            "fire_sound": "sounds/fire.ogg",
        },
        "super_bullet": {
            "score_cast": 200,
            "life_value": 300,
            "speed": 3,
            "acc_distance_1": 400,
            "acc_distance_2": 300,
            "damage": 300,
            "fire_delay": 300,
            "image": "images/super_bullet.png",
            "fire_sound": "sounds/super_fire.ogg",
            "firehit_sound": "sounds/firehit.ogg",
        },
    },
    "myf_slave": {
        "images": ["images/my_slave_fighter1.png", "images/my_slave_fighter2.png"],
        "first_pos": (-100, 600),
        "shield_value": 50,
        "shield_recharge_step": 7,
        "score_cast": 100,
        "max_limit": 7,
        "min_limit": 2,
        "life_value": 500,
        "bullet_speed": 10,
        "bullet_color": "light_yellow",
        "bullet_damage": 20,
        "bullet_radius": 9,
        "fire_delay": 15,
        "trace_fire_delay": 30,
        "fire_sound": "sounds/fire.ogg",
        "firehit_sound": "sounds/firehit.ogg",
        "fire_sound_volume": 0.2,
        "firehit_sound_volume": 0.2,
    },
}

==> SightTraining-0.1.19-py3-none-any.whl: spacedefense/config.py <==
configmap = {
    "display_width": 1280,
    "display_height": 720,
    "fullscreen": False,
    "game_time": 600,
    "bgm": {
        "sound": "sounds/bgm3.ogg",
        "sound_volume": 1.0,
    },
    "game_cover": {
        "cover_image": "images/game_cover.webp",
        "cover_win": "images/game_cover_win.webp",
        "cover_loss": "images/game_cover_loss.webp",
    },
    "background": {
        "vmove": {
            "image_sequence_group": ["images/vmove_cambg2", "images/vmove_cambg1"],
            "images": ["images/vmove_cambg1/cambg_003.webp"],
        },
        "scale": {
            "image": "images/scale_cambg1.webp",
        },
        "type": "vmove",
    },
    "stage_angry": {
        "sound": "sounds/stage_angry.ogg",
        "sound_volume": 0.4,
    },
    "stage_pre": {
        "images": "images/stage_pre.png",
        "sound": "sounds/stage_pre.ogg",
        "sound_volume": 0.4,
    },
    "stage_start": {
        "sound": "sounds/stage_start.ogg",
        "sound_volume": 0.4,
    },
    "stage_end_win": {
        "sound": "sounds/stage_end_win.ogg",
        "sound_volume": 0.4,
    },
    "stage_end_loss": {
        "sound": "sounds/stage_end_loss.ogg",
        "sound_volume": 0.4,
    },
    "sufo_join": {
        "sound": "sounds/sufo_join.ogg",
        "sound_volume": 0.4,
    },
    "smyf_join": {
        "sound": "sounds/smyf_join.ogg",
        "sound_volume": 0.4,
    },
    "my_score_step": 5,
    "ufo_score_step": 3,
    "unit_collision_cooldown": 1000,
    "ufo_master": {
        "image_sequence": "images/ufo_master",
        "images": ["images/ufo_master.png"],
        "first_pos": (720, 100),
        "life_value": 30000,
        "shield_value": 1000,
        "shield_recharge_step": 1,
        "bullet_color": "cyan",
        "bullet_speed": 7,
        "bullet_damage": 20,
        "bullet_radius": 10,
        "trace_fire_delay": 30,
        "fire_interceptor_delay": 20,
        "fire_delay": 30,
        "fire_score": 5,
        "fire_sound": "sounds/ufo_fire.ogg",
        "firehit_sound": "sounds/ufo_firehit.ogg",
        "fire_sound_volume": 0.4,
        "firehit_sound_volume": 0.4,
    },
    "ufo_slave": {
        "image_sequence": "images/ufo_slave",
        "images": ["images/ufo_slave1.png", "images/ufo_slave2.png"],
        "first_pos": (400, -100),
        "score_cast": 50,
        "max_limit": 8,
        "min_limit": 3,
        "shield_value": 100,
        "shield_recharge_step": 5,
        "life_value": 500,
        "bullet_speed": 9,
        "bullet_color": "cyan",
        "bullet_damage": 10,
        "bullet_radius": 8,
        "trace_fire_delay": 40,
        "fire_interceptor_delay": 20,
        "fire_delay": 15,
        "fire_sound": "sounds/ufo_fire.ogg",
        "firehit_sound": "sounds/ufo_firehit.ogg",
        "fire_sound_volume": 0.4,
        "firehit_sound_volume": 0.4,
    },
    "myf_master": {
        "life_value": 700,
        "shield_value": 300,
        "shield_recharge_step": 3,
        "speed_x": 8,
        "image_sequence": "images/myf_master",
        "image": "images/master_fighter.webp",
        "firehit_sound": "sounds/firehit.ogg",
        "fire_sound_volume": 0.4,
        "firehit_sound_volume": 0.4,
        "upgrade_cast": 100,
        "level1": {
            "bullet_color": "light_yellow",
            "bullet_per_num": 2,
            "bullet_speed": 15,
            "bullet_damage": 10,
            "bullet_radius": 5,
            "fire_delay": 8,
            "fire_sound": "sounds/fire.ogg",
        },
        "level2": {
            "bullet_color": "light_yellow",
            "bullet_per_num": 1,
            "bullet_speed": 10,
            "bullet_damage": 40,
            "bullet_radius": 8,
            "fire_delay": 12,
            "fire_sound": "sounds/fire.ogg",
        },
        "level3": {
            "bullet_color": "light_yellow",
            "bullet_per_num": 2,
            "bullet_speed": 7,
            "bullet_damage": 3,
            "bullet_radius": 5,
            "fire_delay": 10,
            "fire_sound": "sounds/fire.ogg",
        },
        "super_bullet": {
            "score_cast": 200,
            "life_value": 300,
            "speed": 3,
            "acc_distance_1": 400,
            "acc_distance_2": 300,
            "damage": 200,
            "fire_delay": 200,
            "image": "images/super_bullet.webp",
            "fire_sound": "sounds/super_fire.ogg",
            "firehit_sound": "sounds/firehit.ogg",
        },
    },
    "myf_slave": {
        "images": ["images/my_slave_fighter1.webp", "images/my_slave_fighter2.webp"],
        "first_pos": (-10, 300),
        "shield_value": 100,
        "shield_recharge_step": 5,
        "score_cast": 100,
        "max_limit": 7,
        "min_limit": 2,
        "life_value": 500,
        "bullet_speed": 10,
        "bullet_color": "light_yellow",
        "bullet_damage": 20,
        "bullet_radius": 8,
        "fire_delay": 15,
        "trace_fire_delay": 30,
        "fire_sound": "sounds/fire.ogg",
        "firehit_sound": "sounds/firehit.ogg",
        "fire_sound_volume": 0.4,
        "firehit_sound_volume": 0.4,
    },
}
